reschema
========

This directory contains a library for parsing <rest-schema> objects
that describe a REST API.  The <rest-schema> format is described in GL4v2.

License
=======

Copyright (c) 2015 Riverbed Technology, Inc.

Reschema is licensed under the terms and conditions of the MIT License
accompanying the software ("License").  Reschema is distributed "AS IS" as set
forth in the License.  Reschema requires the download and usage of certain
third party software from third party websites.  All such third party software
is licensed by the applicable third party licensors under the terms and
conditions (including, without limitation, warranty and liability disclaimers)
offered by such third party licensors. You acknowledge that you are responsible
for obtaining and complying with any licenses necessary to operate any such
third party software.  Riverbed Technology, Inc. disclaims all representations,
warranties and liability relating to such third party software.





